@@ -1,7 +1,7 @@
 package Tree::FromStruct;
 
-our $DATE = '2016-03-26'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-29'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 require Code::Includable::Tree::FromStruct;
 
@@ -30,7 +30,7 @@ Tree::FromStruct - Build a tree object from hash structure
 
 =head1 VERSION
 
-This document describes version 0.02 of Tree::FromStruct (from Perl distribution Tree-FromStruct), released on 2016-03-26.
+This document describes version 0.03 of Tree::FromStruct (from Perl distribution Tree-FromStruct), released on 2016-03-29.
 
 =head1 SYNOPSIS
 
@@ -79,15 +79,15 @@ In your code to build a tree:
 Building a tree manually can be tedious: you have to connect the parent and
 the children nodes together:
 
- my $root = My::Class->new(...);
- my $child1 = My::Class->new(...);
- my $child2 = My::Class->new(...);
+ my $root = My::TreeNode->new(...);
+ my $child1 = My::TreeNode->new(...);
+ my $child2 = My::TreeNode->new(...);
 
- $root->children($child1, $child2);
+ $root->children([$child1, $child2]);
  $child1->parent($root);
  $child2->parent($root);
 
- my $grandchild1 = My::Class->new(...);
+ my $grandchild1 = My::TreeNode->new(...);
  ...
 
 This module provides a convenience function to build a tree of objects in a
@@ -125,6 +125,9 @@ feature.
 L<Role::TinyCommons::Tree::FromStruct> if you want to use this functionality via
 consuming a role.
 
+Other ways to create tree: L<Tree::FromText>, L<Tree::FromTextLines>,
+L<Tree::Create::Callback>, L<Tree::Create::Size>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
